#
# spec file for package kernel-install-tools
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kernel-install-tools
Version:        0.3.0
Release:        2.4
Summary:        Useful tools for installing self-built kernels
Group:          Development/Tools/Other
License:        GPL-2.0-only
URL:            https://github.com/jeffmahoney/kernel-install-tools
Source:         %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
Requires:       openssl
%ifarch ia64 %ix86 x86_64 aarch64 %arm riscv64
Requires:       mozilla-nss-tools
Requires:       pesign
%else
Requires:       kernel-default-devel
%endif

%description
A collection of tools useful for installing self-built kernels.

In addition to the baseline /sbin/installkernel, this package includes
several tools for properly signing and installing kernels and certificates
for use on systems with UEFI Secure Boot enabled.

%prep
%setup -q

%build

%install
%make_install

%if 0%{?suse_version} >= 1550
mv %{buildroot}/sbin/installkernel %{buildroot}/usr/sbin/installkernel
%endif

%files
%license COPYING
%doc README.md
%{_bindir}/sbtool-genkey
%{_bindir}/sbtool-sign-kernel
%{_sbindir}/sbtool-enroll-key
%if 0%{?suse_version} >= 1550
%{_sbindir}/installkernel
%else
/sbin/installkernel
%endif

%changelog
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Tue Mar 29 2022 jeffm@suse.com
- Update to version v0.3.0:
  * specfile: accept OBS cleanups
  * specfile: fix UsrMerge support
  * specfile: silence OBS warning about no-binary
  * specfile: fix license tag
  * Makefile: install the installkernel script directly in /sbin
  * installkernel: Don't force hostonly
* Tue Jan 11 2022 Jeff Mahoney <jeffm@suse.com>
- Integrate required spec file changes for non-x86.
* Mon Jan 10 2022 jeffm@suse.com
- Update to version 0.2.10:
  * Support non-x86 architectures.
* Wed Nov 10 2021 Jeff Mahoney <jeffm@suse.com>
- Cleaned up rpmlint warnings and made usrmerge support cleaner.
* Wed Nov 10 2021 jeffm@suse.com
- Update to version 0.2.8:
  * Makefile: create symlink to /sbin/installkernel if /sbin != /usr/sbin
  * installkernel: remove 'function' bashism
* Wed Nov 10 2021 Jeff Mahoney <jeffm@suse.com>
- Changed set_version to manual and added usrmerge distinction.
* Wed Nov 10 2021 Jeff Mahoney <jeffm@suse.com>
- Changed obs_scm mode to manual and set_version mode to buildtime.
* Sun Aug 29 2021 jeffm@suse.com
- Update to version 0.2.6:
  * scripts: move messages around to better handle skipped enrollment
  * sbtool-sign-kernel: handle kernels without signing keys configured
  * sbtool-enroll-key: handle non-UEFI systems more gracefully
  * sbtool-sign-kernel: do not automatically enroll kernel-built certificates
  * scripts: fix paths to other scripts
  * packaging: fix up spec file after initial OBS builds
* Fri Aug 27 2021 Jeff Mahoney <jeffm@suse.com>
- Initial packaging.
